@@ -2,7 +2,7 @@ from __future__ import unicode_literals
 import datetime
 import copy
 
-VERSION = "0.0.9"
+VERSION = "0.0.10"
 
 
 class classproperty(object):
@@ -18,11 +18,14 @@ class QMixin(object):
     AND = 'AND'
     OR = 'OR'
     NOT = 'NOT'
+    UNION = 'UNION'
 
     def _combine(self, other, conn):
         return Operator(conn, self, other)
 
     def __or__(self, other):
+        if isinstance(other, Queryset):
+            return self._combine(other, self.UNION)
         return self._combine(other, self.OR)
 
     def __and__(self, other):
@@ -76,6 +79,8 @@ class F(object):
 
 
 class Q(QMixin):
+    _mode = "MYSQL"
+
     lookup_types = [
         'icontains', 'istartswith',  'iendswith',
         'contains', 'startswith',  'endswith',
@@ -100,15 +105,27 @@ class Q(QMixin):
 
     __nonzero__ = __bool__
 
+    @property
+    def date_format(self):
+        if self._mode == 'SQLSERVER':
+            return "%Y-%d-%m"
+        return "%Y-%m-%d"
+
+    @property
+    def datetime_format(self):
+        if self._mode == 'SQLSERVER':
+            return "%Y-%d-%m %H:%M:%S"
+        return "%Y-%m-%d %H:%M:%S"
+
     def _get_value(self, value):
         if isinstance(value, int) or isinstance(value, float):
             return unicode(value)
 
         if isinstance(value, datetime.datetime):
-            return "'%s'" % value.strftime("%Y-%m-%d %H:%M:%S")
+            return "'%s'" % value.strftime(self.datetime_format)
 
         if isinstance(value, datetime.date):
-            return "'%s'" % value.strftime("%Y-%m-%d")
+            return "'%s'" % value.strftime(self.date_format)
 
         if isinstance(value, list) or isinstance(value, set):
             return ", ".join([self._get_value(item) for item in value])
@@ -179,9 +196,8 @@ class Q(QMixin):
 
 class SQLQuery(object):
 
-    def __init__(self, table=None, sql_mode="MYSQL"):
-        if table:
-            self._table = table
+    def __init__(self, table=None, sql_mode="MYSQL", sql=None):
+        self._table = table
         self.sql_mode = sql_mode
         self._values = ["*"]
         self._order_by = []
@@ -191,6 +207,24 @@ class SQLQuery(object):
         self._excludes = Q()
         self._extra = {}
         self._limits = None
+        self._sql = sql
+
+    def has_filters(self,):
+        return self._order_by or self._group_by or self._joins\
+            or self._filters or self._excludes or self._extra \
+            or self._limits or self._values != ['*']
+
+    def _q(self, *args, **kwargs):
+        conds = Q()
+        conds._mode = self.sql_mode
+        for arg in args:
+            if issubclass(arg.__class__, QMixin):
+                arg._mode = self.sql_mode
+                conds &= arg
+
+        _conds = Q(**kwargs)
+        _conds._mode = self.sql_mode
+        return conds & _conds
 
     def _clone(self,):
         return copy.deepcopy(self)
@@ -202,20 +236,12 @@ class SQLQuery(object):
 
     def filter(self, *args, **kwargs):
         clone = self._clone()
-        for arg in args:
-            if issubclass(arg.__class__, QMixin):
-                clone._filters &= arg
-
-        clone._filters &= Q(**kwargs)
+        clone._filters &= self._q(*args, **kwargs)
         return clone
 
     def exclude(self, *args, **kwargs):
         clone = self._clone()
-        for arg in args:
-            if issubclass(arg.__class__, QMixin):
-                clone._excludes &= arg
-
-        clone._excludes &= Q(**kwargs)
+        clone._excludes &= self._q(*args, **kwargs)
         return clone
 
     def order_by(self, *args):
@@ -272,7 +298,7 @@ class SQLCompiler(object):
         extra_where = self.get_extra_where()
 
         if filters or extra_where:
-            return "WHERE " + " ".join([item for item in [filters, extra_where] if item])
+            return "WHERE " + " AND ".join([item for item in [filters, extra_where] if item])
 
     def get_order_by(self,):
         conds = []
@@ -314,14 +340,22 @@ class SQLCompiler(object):
         if self._limits and self.sql_mode == "SQL_SERVER":
             return "TOP {0}".format(self._limits.stop)
 
-    def _compile(self):
-        sql_all = ["SELECT", self.get_top(), self.get_columns(),
-                   "FROM", self.get_table(),
-                   self.get_joins(), self.get_where(),
-                   self.get_group_by(), self.get_order_by(),
-                   self.get_limits()]
+    def get_sql_structure(self):
+        if self._sql:
+            if not self.has_filters():
+                return [self._sql]
+            table = u"(%s) as union1" % self._sql
+        else:
+            table = self.get_table()
 
-        return " ".join([item for item in sql_all if item])
+        return ["SELECT", self.get_top(), self.get_columns(),
+                "FROM", table,
+                self.get_joins(), self.get_where(),
+                self.get_group_by(), self.get_order_by(),
+                self.get_limits()]
+
+    def _compile(self):
+        return " ".join([unicode(item) for item in self.get_sql_structure() if item])
 
     def __repr__(self):
         return self._compile()
@@ -332,6 +366,9 @@ class SQLCompiler(object):
     def sql(self,):
         return self.__str__()
 
+    def __or__(self, other):
+        return self.__class__(sql="%s UNION %s" % (self, other))
+
 
 class Queryset(SQLCompiler, SQLQuery):
     pass
